==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-73.js <==
//  "smtp" : [ "mysql.png" , "http://www.mysql.com/" ] ,
dispMUA.arDispMUAAllocation["s"] =
{
  "schalk&friends powered by htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "sendnewsletter/parallel by epublica" : [ "epublica.png" , "http://www.epublica.de/" ] ,
  "smarttools publishing serienmailer" : [ "smarttools.png" ] ,
  "suse linux openexchange server" : [ "suse.png" , "http://www.suse.com/" ] ,
  "sun one messenger express" : [ "sun_one.png" , "http://www.sun.com/" ] ,
  "smtp client for ibm as400" : [ "ibm.png" , "http://www.ibm.com/" ] ,
  "spiegel verlag webmailer" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "samlogic mailing system" : [ "samlogic_mailing_system.png" , "http://www.samlogic.net/multimailer/multimailer.htm" ] ,
  "striata communications" : [ "striata.png" , "http://www.striata.com/" ] ,
  "smtpit - filemaker pro" : [ "filemaker.png" ] ,
  "sevactivex smtp mailer" : [ "sev.png" ] ,
  "sun outlook connector" : [ "sun_outlook.png" , "http://www.sun.com/" ] ,
  "steinbrecher software" : [ "steinbrecher.png" ] ,
  "saunalahti webmail" : [ "saunalahti_fi.png" , "http://www.saunahahti.fi/" ] ,
  "supermailerscript" : [ "supermailerscript.png" , "http://www.supermailer.de/" ] ,
  "stroede cmartpost" : [ "stroede.png" ] ,
  "sse-unimatrix-one" : [ "1und1.png" , "http://www.1and1.co.uk/" ] ,
  "stepstone mailer" : [ "stepstone.png" , "http://www.stepstone.de/" ] ,
  "sav materiel.net" : [ "materiel.png" ] ,
  "sonicmailer pro" : [ "sonicmailer_pro.png" , "http://www.triexa.com/" ] ,
  "smartstore.biz" : [ "smartstore.png" , "http://www.smartstore.com/" ] ,
  "sky-newsletter" : [ "sky-scripts.png" , "http://www.sky-scripts.de/" ] ,
  "sibnet webmail" : [ "sibnet.png" , "http://mail.sibnet.ru/" ] ,
  "sevsmtp mailer" : [ "sev.png" ] ,
  "sysaid server" : [ "sysaid.png" ] ,
  "store-mailer/" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "sohu web mail" : [ "sohu_com.png" , "http://www.sohu.com/" ] ,
  "sina freemail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "staroffice21" : [ "staroffice21.png" ] ,
  "squirrelmail" : [ "squirrelmail.png" , "http://www.squirrelmail.org/" ] ,
  "spon-webmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "smtpjavamail" : [ "smtpjavamail.png" , "http://java.sun.com/products/javamail/" ] ,
  "sina webmail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "simorganizer" : [ "simorganizer.png" ] ,
  "shop to date" : [ "shoptodate.png" , "http://www.shoptodate.de/" ] ,
  "serendipity/" : [ "serendipity.png" ] ,
  "send::around" : [ "sendaround.png" , "http://www.sendaround.de/" ] ,
  "scrubby mail" : [ "scrubtheweb.png" ] ,
  "svn::notify" : [ "subversion.png" ] ,
  "stumbleupon" : [ "stumbleupon.png" ] ,
  "streamserve" : [ "streamserve.png" ] ,
  "storeforyou" : [ "storeforyou.png" , "http://www.storeforyou.de/" ] ,
  "sqli mailer" : [ "sqli_com.png" , "http://www.sqli.com/" ] ,
  "software602" : [ "software602.png" , "http://www.software602.com/" ] ,
  "snappermail" : [ "snappermail.png" ] ,
  "smartagent/" : [ "smartagent.png" ] ,
  "simplecheck" : [ "simplecheck.png" ] ,
  "simple mail" : [ "simple-mail.png" , "http://telega.phpnet.us/simplemail/" ] ,
  "shopexpress" : [ "shopexpress.png" ] ,
  "sendblaster" : [ "sendblaster.png" ] ,
  "sa-smtpmail" : [ "softartisans.png" ] ,
  "symbian os" : [ "symbian_os.png" , "http://www.symbian.com/" ] ,
  "su-webmail" : [ "stockholm_uni.png" ] ,
  "strongmail" : [ "strongmail.png" ] ,
  "stringdata" : [ "post_sk.png" , "http://www.post.sk/" ] ,
  "streamsend" : [ "streamsend.png" ] ,
  "staroffice" : [ "staroffice.png" ] ,
  "soupermail" : [ "soupermail.png" , "http://soupermail.sourceforge.net/" ] ,
  "smoothwall" : [ "smoothwall.png" , "http://www.smoothwall.net/" ] ,
  "simplemail" : [ "python.png" , "http://www.python-forum.de/post-18144.html" ] ,
  "sendemail-" : [ "sendemail.png" ] ,
  "scenario m" : [ "scenario-m_de.png" , "http://www.scenario-m.de/" ] ,
  "satamatics" : [ "satamatics.png" ] ,
  "synckolab" : [ "kolab.png" , "http://www.kolab.org/" ] ,
  "swiftdove" : [ "swiftdove.png" ] ,
  "svnmailer" : [ "subversion.png" ] ,
  "spnetmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "spicebird" : [ "spicebird.png" ] ,
  "speedmail" : [ "speedmail.png" ] ,
  "sake mail" : [ "sake_mail.png" ] ,
  "syndmail" : [ "syndmail.png" ] ,
  "sylpheed" : [ "sylpheed.png" ] ,
  "sun java" : [ "java.png" , "http://www.sun.com/" ] ,
  "steganos" : [ "steganos.png" ] ,
  "sitemail" : [ "sitemail.png" ] ,
  "sinamail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "sendsmtp" : [ "sendsmtp.png" ] ,
  "sendmail" : [ "sendmail.png" ] ,
  "swwwing" : [ "swwwing.png" ] ,
  "spiral/" : [ "spiral.png" , "http://www.smp.ne.jp/" ] ,
  "soom.cz" : [ "soom_cz.png" , "http://www.soom.cz/index.php?name=projects/mail/main" ] ,
  "strato" : [ "strato.png" , "http://www.strato.de/" ] ,
  "smtpit" : [ "smtpit.png" ] ,
  "siebel" : [ "siebel.png" ] ,
  "sidoko" : [ "siegel-edv_de.png" , "http://www.siegel-edv.de/" ] ,
  "scalix" : [ "scalix.png" ] ,
  "sympa" : [ "sympa.png" ] ,
  "swift" : [ "swift.png" ] ,
  "swaks" : [ "swaks.png" , "http://jetmore.org/john/code/#swaks" ] ,
  "sumo/" : [ "sumo.png" ] ,
  "smtpc" : [ "smtpc.png" ] ,
  "slrn/" : [ "slrn.png" ] ,
  "slrn " : [ "slrn.png" ] ,
  "sharp" : [ "sharp.png" ] ,
  "setia" : [ "setia.png" ] ,
  "sesna" : [ "sesna.png" , "http://maple.snowdrift.cc/?sesna%2FV2" ] ,
  "sup/" : [ "ruby.png" , "http://sup.rubyforge.org/" ] ,
  "sap " : [ "sap.png" ] ,
  "smf" : [ "simplemachines.png" , "http://www.simplemachines.org/" ] ,
  "sk " : [ "sk.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-73.js <==
//  "smtp" : [ "mysql.png" , "http://www.mysql.com/" ] ,
dispMUA.arDispMUAAllocation["s"] =
{
  "schalk&friends powered by htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "sendnewsletter/parallel by epublica" : [ "epublica.png" , "http://www.epublica.de/" ] ,
  "smarttools publishing serienmailer" : [ "smarttools.png" ] ,
  "suse linux openexchange server" : [ "suse.png" , "http://www.suse.com/" ] ,
  "sun one messenger express" : [ "sun_one.png" , "http://www.sun.com/" ] ,
  "smtp client for ibm as400" : [ "ibm.png" , "http://www.ibm.com/" ] ,
  "spiegel verlag webmailer" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "seven enterprise gateway" : [ "seven.png" , "http://www.seven.com/" ] ,
  "samlogic mailing system" : [ "samlogic_mailing_system.png" , "http://www.samlogic.net/multimailer/multimailer.htm" ] ,
  "striata communications" : [ "striata.png" , "http://www.striata.com/" ] ,
  "smtpit - filemaker pro" : [ "filemaker.png" ] ,
  "sevactivex smtp mailer" : [ "sev.png" ] ,
  "sun outlook connector" : [ "sun_outlook.png" , "http://www.sun.com/" ] ,
  "steinbrecher software" : [ "steinbrecher.png" ] ,
  "surfino newsreader" : [ "surfino.png" , "http://newsreader.surfino.com/" ] ,
  "saunalahti webmail" : [ "saunalahti_fi.png" , "http://www.saunahahti.fi/" ] ,
  "supermailerscript" : [ "supermailerscript.png" , "http://www.supermailer.de/" ] ,
  "stroede cmartpost" : [ "stroede.png" ] ,
  "sse-unimatrix-one" : [ "1und1.png" , "http://www.1and1.co.uk/" ] ,
  "stepstone mailer" : [ "stepstone.png" , "http://www.stepstone.de/" ] ,
  "sav materiel.net" : [ "materiel.png" ] ,
  "sonicmailer pro" : [ "sonicmailer_pro.png" , "http://www.triexa.com/" ] ,
  "smartstore.biz" : [ "smartstore.png" , "http://www.smartstore.com/" ] ,
  "sky-newsletter" : [ "sky-scripts.png" , "http://www.sky-scripts.de/" ] ,
  "sibnet webmail" : [ "sibnet.png" , "http://mail.sibnet.ru/" ] ,
  "sevsmtp mailer" : [ "sev.png" ] ,
  "sysaid server" : [ "sysaid.png" ] ,
  "store-mailer/" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "sohu web mail" : [ "sohu_com.png" , "http://www.sohu.com/" ] ,
  "sina freemail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "startaid.com" : [ "startaid_com.png" , "http://www.startaid.com/" ] ,
  "staroffice21" : [ "staroffice21.png" ] ,
  "squirrelmail" : [ "squirrelmail.png" , "http://www.squirrelmail.org/" ] ,
  "spon-webmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "smtpjavamail" : [ "smtpjavamail.png" , "http://java.sun.com/products/javamail/" ] ,
  "sina webmail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "simorganizer" : [ "simorganizer.png" ] ,
  "shop to date" : [ "shoptodate.png" , "http://www.shoptodate.de/" ] ,
  "serendipity/" : [ "serendipity.png" ] ,
  "send::around" : [ "sendaround.png" , "http://www.sendaround.de/" ] ,
  "scrubby mail" : [ "scrubtheweb.png" ] ,
  "svn::notify" : [ "subversion.png" ] ,
  "stumbleupon" : [ "stumbleupon.png" ] ,
  "streamserve" : [ "streamserve.png" ] ,
  "storeforyou" : [ "storeforyou.png" , "http://www.storeforyou.de/" ] ,
  "sqli mailer" : [ "sqli_com.png" , "http://www.sqli.com/" ] ,
  "software602" : [ "software602.png" , "http://www.software602.com/" ] ,
  "snappermail" : [ "snappermail.png" ] ,
  "smartagent/" : [ "smartagent.png" ] ,
  "simplecheck" : [ "simplecheck.png" ] ,
  "simple mail" : [ "simple-mail.png" , "http://telega.phpnet.us/simplemail/" ] ,
  "shopexpress" : [ "shopexpress.png" ] ,
  "sendblaster" : [ "sendblaster.png" ] ,
  "sa-smtpmail" : [ "softartisans.png" ] ,
  "symbian os" : [ "symbian_os.png" , "http://www.symbian.com/" ] ,
  "su-webmail" : [ "stockholm_uni.png" ] ,
  "strongmail" : [ "strongmail.png" ] ,
  "stringdata" : [ "post_sk.png" , "http://www.post.sk/" ] ,
  "streamsend" : [ "streamsend.png" ] ,
  "staroffice" : [ "staroffice.png" ] ,
  "soupermail" : [ "soupermail.png" , "http://soupermail.sourceforge.net/" ] ,
  "smoothwall" : [ "smoothwall.png" , "http://www.smoothwall.net/" ] ,
  "simplemail" : [ "python.png" , "http://www.python-forum.de/post-18144.html" ] ,
  "sendemail-" : [ "sendemail.png" ] ,
  "scenario m" : [ "scenario-m_de.png" , "http://www.scenario-m.de/" ] ,
  "satamatics" : [ "satamatics.png" ] ,
  "synckolab" : [ "kolab.png" , "http://www.kolab.org/" ] ,
  "swiftdove" : [ "swiftdove.png" ] ,
  "svnmailer" : [ "subversion.png" ] ,
  "spnetmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "spicebird" : [ "spicebird.png" ] ,
  "speedmail" : [ "speedmail.png" ] ,
  "sake mail" : [ "sake_mail.png" ] ,
  "syndmail" : [ "syndmail.png" ] ,
  "sylpheed" : [ "sylpheed.png" ] ,
  "sun java" : [ "java.png" , "http://www.sun.com/" ] ,
  "steganos" : [ "steganos.png" ] ,
  "spaps.de" : [ "spaps_de.png" , "http://www.spaps.de/" ] ,
  "smtpmail" : [ "smtpmail.png" , "http://fileup.softartisans.com/fileup-276.aspx" ] ,
  "sitemail" : [ "sitemail.png" ] ,
  "sinamail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "sendsmtp" : [ "sendsmtp.png" ] ,
  "sendmail" : [ "sendmail.png" ] ,
  "synapse" : [ "synapse.png" , "http://synapse.ararat.cz/" ] ,
  "swwwing" : [ "swwwing.png" ] ,
  "spiral/" : [ "spiral.png" , "http://www.smp.ne.jp/" ] ,
  "soom.cz" : [ "soom_cz.png" , "http://www.soom.cz/index.php?name=projects/mail/main" ] ,
  "strato" : [ "strato.png" , "http://www.strato.de/" ] ,
  "smtpit" : [ "smtpit.png" ] ,
  "skyrix" : [ "skyrix.png" , "http://www.skyrix.com/" ] ,
  "siebel" : [ "siebel.png" ] ,
  "sidoko" : [ "siegel-edv_de.png" , "http://www.siegel-edv.de/" ] ,
  "scalix" : [ "scalix.png" ] ,
  "sympa" : [ "sympa.png" ] ,
  "swift" : [ "swift.png" ] ,
  "swaks" : [ "swaks.png" , "http://jetmore.org/john/code/#swaks" ] ,
  "sumo/" : [ "sumo.png" ] ,
  "smtpc" : [ "smtpc.png" ] ,
  "slrn/" : [ "slrn.png" ] ,
  "slrn " : [ "slrn.png" ] ,
  "sharp" : [ "sharp.png" ] ,
  "setia" : [ "setia.png" ] ,
  "sesna" : [ "sesna.png" , "http://maple.snowdrift.cc/?sesna%2FV2" ] ,
  "sup/" : [ "ruby.png" , "http://sup.rubyforge.org/" ] ,
  "sap " : [ "sap.png" ] ,
  "smf" : [ "simplemachines.png" , "http://www.simplemachines.org/" ] ,
  "sk " : [ "sk.png" ] ,
}
